Learn R Programming

nat.templatebrains (version 0.6.2)

download_reg_repo: Download and register git repository containing registrations

Description

Note that these extra registrations will be downloaded to a standard location on your hard drive that will be used for one session to the next. See examples and local_reg_dir_for_url.

Usage

download_reg_repo(url, localdir = NULL, ...)

Arguments

url
Location of one or more remote git repositories. Can accept partial github specifications of the form "/".
localdir
Full path to local checkout location of git repository. When localdir=NULL, the default, a sensible location is chosen using the rappdirs function.
...
additional arguments passed to git2r::clone e.g. credentials for private repo.

See Also

add_reg_folders, local_reg_dir_for_url, git2r::clone

update_reg_repos

Examples

Run this code
## find the root location of all registration directories
local_reg_dir_for_url()
## Not run: 
# ## Add the two main jefferislab bridging and mirroring registration
# # collections for Drosophila brains from github.com.
# download_reg_repo("jefferislab/BridgingRegistrations")
# download_reg_repo("jefferislab/MirrorRegistrations")
# 
# ## update all current registration repositories
# update_reg_repos()
# ## End(Not run)

Run the code above in your browser using DataLab