Learn R Programming

nat.templatebrains (version 0.6.2)

as.templatebrain: Use image file or other object to initialise template brain

Description

Use image file or other object to initialise template brain

Usage

as.templatebrain(x, ...)
"as.templatebrain"(x, ...)
"as.templatebrain"(x, name = NULL, regName = NULL, ...)

Arguments

x
object used to construct the templatebrain, either a character vector with the path to a file or an im3d object.
...
additional named arguments passed to methods and then on to templatebrain that will be added as fields to the templatebrain object.
name,regName
name and short name of the template brain. Will use the filename (minus final extension) by default for both fields.

Value

A list with class templatebrain.

See Also

im3d

Examples

Run this code
# Make templatebrain object using image info from the template brain NRRD file
nhdr=system.file('images','FCWB.nhdr', package='nat.templatebrains')
as.templatebrain(nhdr, name = "FlyCircuit Whole Brain")

Run the code above in your browser using DataLab