local_reg_dir_for_url(url = NULL)url=NULL defaults
to giving the base path.download_reg_repo to install from
a github repository such as this one of ours:.
jefferislab/BridgingRegistrationsNote that this folder will always be the same place on a machine i.e. this defines a consistent, persistent location on disk to store data across sesssions.
When called with a url, a SHA1 hash will be calculated for the URL and appended to the basepath. This should ensure that locations derived from different URLs do not clash.
download_reg_repo