Learn R Programming

nat.templatebrains (version 0.6.2)

nat.templatebrains-package: NeuroAnatomy Toolbox add-on package for handling template brains

Description

This package provides a class templatebrain that stores key information about reference brains along with helper functions to simplify transformation of data between template brains (a.k.a bridging) and mirroring of data within a template brain.

Arguments

Helper functions

Easy-to-use functions for transforming data from one template brain to another, displaying slices alongside 3D data, etc. are provided. See especially xform_brain, mirror_brain and plot3d.templatebrain.

Package options

  • options('nat.templatebrains.regdirs') specifies a character vector of directories containing registrations.
It is strongly recommended
  • to use the download_reg_repo to download registration folders where possible. This will automatically add the new folders to this option both in the current session and on package startup.
  • to use add_reg_folders to add additional directories to the search list.
Note that registration directories will be searched in the order that they are listed. It is therefore strongly recommended that individual registrations have globally unique names.

See Also

nat

Examples

Run this code
## Not run: 
# #
# 
# # manually add a new directory containing registrations to the search list
# options(nat.templatebrains.regdirs=union(
#   getOption('nat.templatebrains.regdirs'), "/my/new/path"))
# 
# 
# ## same, but override any built-in registration by putitng the new path
# # at the first position in the search list
# options(nat.templatebrains.regdirs=union("/my/new/path"),
#   getOption('nat.templatebrains.regdirs'))
# ## End(Not run)

Run the code above in your browser using DataLab