Learn R Programming

nat.templatebrains (version 0.4.1)

nat.templatebrains-package: NeuroAnatomy Toolbox add-on package for handling template brains

Description

This package provides a class templatebrain that stores key information about referennce brains along with helpfer functions to simplify transformation of data between template brains (a.k.a bridging) and mirroring of data within a template brain. Presently there

Arguments

Helper functions

Easy-to-use functions for transforming data from one template brain to another, displaying slices alongside 3D data, etc. are provided. See especially xform_brain, mirror_brain and plot3d.templatebrain.

Package options

  • options('nat.templatebrains.regdirs') specifies a character vector of directories containing registrations.

Note that registration directories should be specified as full paths and will be searched in the order that they are listed. Registrations should therefore have globally unique names.

See Also

nat

Examples

Run this code
options(nat.templatebrains.regdirs=union(
  getOption('nat.templatebrains.regdirs'), "/my/new/path"))

Run the code above in your browser using DataLab