Learn R Programming

nat.templatebrains (version 0.4.1)

templatebrain-meths: Template brain methods

Description

is.templatebrain tests if object is of class templatebrain

as.character.templatebrain converts template brain to character vector representation (normally used to extract the short name i.e. regName).

print.templatebrain prints templatebrain information in human-readable form

as.im3d converts a template brain to a nat::im3d object; this is probably useful for developers.

origin extracts the space origin of a templatebrain object.

dim extracts the dimensions (in number of pixels) of the image associated with a templatebrain object.

voxdims extracts the dimensions (in number of pixels) of the image associated with a templatebrain object.

boundingbox extracts the boundingbox (in calibrated spatial units, typically microns) of the image associated with a templatebrain object. See boundingbox for details.

Usage

is.templatebrain(x)

## S3 method for class 'templatebrain': as.character(x, field = c("regName", "name"), ...)

## S3 method for class 'templatebrain': print(x, ...)

## S3 method for class 'templatebrain': as.im3d(x, ...)

## S3 method for class 'templatebrain': origin(x, ...)

## S3 method for class 'templatebrain': dim(x, ...)

## S3 method for class 'templatebrain': voxdims(x, ...)

## S3 method for class 'templatebrain': boundingbox(x, ...)

Arguments

x
An object (usually a templatebrain)
field
Which field to use (defaults to 'regName')
...
additional arguments for methods

Value

  • logical

    character vector

See Also

im3d

origin

voxdims

boundingbox

Examples

Run this code
data(FCWB.demo)
is.templatebrain(FCWB.demo)
origin(FCWB.demo)
dim(FCWB.demo)
voxdims(FCWB.demo)
boundingbox(FCWB.demo)

Run the code above in your browser using DataLab