Learn R Programming

nat.templatebrains (version 0.4.1)

xform_brain: Transform 3D object between template brains

Description

Transform 3D object between template brains

Usage

xform_brain(x, sample, reference, via = NULL, ...)

Arguments

x
the 3D object to be transformed
sample
source template brain (e.g. IS2) that data is currently in.
reference
target template brain (e.g. IS2) that data should be transformed into.
via
optional intermediate brain to use when there is no direct bridging registration.
...
extra arguments to pass to xform.

Details

NB the sample and reference brains can either be templatebrain objects or a character string containing the short name of the template e.g. "IS2".

Examples

Run this code
## depends on nat.flybrains package and system CMTK installation
library(nat.flybrains)
# Plot Kenyon cells in their original FCWB template brain
nopen3d()
plot3d(kcs20)
plot3d(FCWB)
# Convert to JFCR2 template brain
kcs20.jfrc2=xform_brain(kcs20, sample = FCWB, reference=JFRC2, .progress='text')
# now plot in the new JFRC2 space
nopen3d()
plot3d(kcs20.jfrc2)
plot3d(JFRC2)
# compare with the untransformed neurons
plot3d(kcs20)
# plot with neuropil sub regions for the left mushroom body
clear3d()
plot3d(kcs20.jfrc2)
# nb "MB.*_L" is a regular expression
plot3d(JFRC2NP.surf, "MB.*_L", alpha=0.3)
# compare with originals - briging registration is no perfect in peduncle
nopen3d()
plot3d(kcs20)
plot3d(FCWBNP.surf, "MB.*_L", alpha=0.3)

Run the code above in your browser using DataLab